@@ -20,6 +20,15 @@ from spatialmath import base
 # from spatialmath.base import argcheck
 # from spatialmath.base import symbolic as sym
 
+try:  # pragma: no cover
+    # print('Using SymPy')
+    from sympy import Matrix
+
+    _symbolics = True
+
+except ImportError:  # pragma: no cover
+    _symbolics = False
+
 _eps = np.finfo(np.float64).eps
 
 # ---------------------------------------------------------------------------------------#
@@ -617,13 +626,11 @@ def rodrigues(w, theta=None):
         else:
             return np.eye(3)
     if theta is None:
-        theta = base.norm(w)
-        w = base.unitvec(w)
+        w, theta = base.unitvec_norm(w)
 
     skw = skew(w)
     return np.eye(skw.shape[0]) + math.sin(theta) * skw + (1.0 - math.cos(theta)) * skw @ skw
 
-
 def h2e(v):
     """
     Convert from homogeneous to Euclidean form
@@ -743,6 +750,31 @@ def homtrans(T, p):
     else:
         raise ValueError('matrices and point data do not conform')
 
+def det(m):
+    """
+    Determinant of matrix
+
+    :param m: any square matrix
+    :type v: array_like(n,n)
+    :return: determinant
+    :rtype: float
+
+    ``det(v)`` is the determinant of the matrix ``m``.
+
+    .. runblock:: pycon
+
+        >>> from spatialmath.base import *
+        >>> norm([3, 4])
+
+    :seealso: :func:`~numpy.linalg.det`
+
+    :SymPy: supported
+    """
+    if m.dtype.kind == 'O':
+        return Matrix(m).det()
+    else:
+        return np.linalg.det(m)
+
 if __name__ == '__main__':  # pragma: no cover
     import pathlib
 
