@@ -15,6 +15,15 @@ import math
 import numpy as np
 from spatialmath.base import getvector
 
+try:  # pragma: no cover
+    # print('Using SymPy')
+    from sympy import Matrix
+
+    _symbolics = True
+
+except ImportError:  # pragma: no cover
+    _symbolics = False
+
 _eps = np.finfo(np.float64).eps
 
 
@@ -60,7 +69,7 @@ def unitvec(v):
     """
 
     v = getvector(v)
-    n = np.linalg.norm(v)
+    n = norm(v)
 
     if n > 100 * _eps:  # if greater than eps
         return v / n
@@ -68,6 +77,35 @@ def unitvec(v):
         return None
 
 
+def unitvec_norm(v):
+    """
+    Create a unit vector
+
+    :param v: any vector
+    :type v: array_like(n)
+    :return: a unit-vector parallel to ``v`` and the norm
+    :rtype: (ndarray(n), float)
+    :raises ValueError: for zero length vector
+
+    ``unitvec(v)`` is a vector parallel to `v` of unit length.
+
+    .. runblock:: pycon
+
+        >>> from spatialmath.base import *
+        >>> unitvec([3, 4])
+
+    :seealso: :func:`~numpy.linalg.norm`
+
+    """
+
+    v = getvector(v)
+    n = np.linalg.norm(v)
+
+    if n > 100 * _eps:  # if greater than eps
+        return (v / n, n)
+    else:
+        return None
+
 def norm(v):
     """
     Norm of vector
@@ -86,8 +124,13 @@ def norm(v):
 
     :seealso: :func:`~spatialmath.base.unit`
 
+    :SymPy: supported
     """
-    return np.linalg.norm(v)
+    v = getvector(v)
+    if v.dtype.kind == 'O':
+        return Matrix(v).norm()
+    else:
+        return np.linalg.norm(v)
 
 
 def isunitvec(v, tol=10):
